<%-- $Id: ajax.jsp 7991 2021-07-01 11:49:17Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
--%>
<%@ page pageEncoding="UTF-8" session="false" contentType="application/json"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Path"
	import="net.sf.basedb.core.ItemNotFoundException"
	import="net.sf.basedb.core.File"
	import="net.sf.basedb.core.SimpleAbsoluteProgressReporter"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.error.ThrowableUtil"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.clients.web.fileupload.FileUploadProgress"
	import="net.sf.basedb.clients.web.fileupload.UploadAbortedException"
	import="org.json.simple.JSONObject"
%>
<%
response.setHeader("Cache-Control", "no-cache, max-age=0");
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
DbControl dc = null;
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
out.clear();
JSONObject json = new JSONObject();
json.put("status", "ok");
try
{
	if ("GetProgress".equals(cmd))
	{
		final FileUploadProgress progress = sc.getSessionSetting("FileUploadProgress");
		final SimpleAbsoluteProgressReporter unpackProgress = sc.getSessionSetting("UnpackProgress");
		
		if (unpackProgress != null)
		{
			json.put("message", unpackProgress.getMessage());
		}
		if (progress != null)
		{
			json.put("file", progress.getCurrentFilename());
			json.put("totalBytes", progress.getTotalBytes());
			json.put("transferredBytes", progress.getTransferredBytes());
			json.put("timeInMillis", progress.getMillisecondsSinceStart());
			json.put("timeInSeconds", progress.getMillisecondsSinceStart() / 1000);
			
			Throwable t = progress.getException();
			if (t != null) 
			{
				sc.setSessionSetting("FileUploadProgress", null);
				sc.setSessionSetting("UnpackProgress", null);
				json.put("status", "error");
				json.put("message", t.getMessage());
				json.put("stacktrace", ThrowableUtil.stackTraceToString(t));
				if (t instanceof WebException)
				{
					WebException we = (WebException)t;
					json.put("title", we.getTitle());
					json.put("message", we.getDetail());
				}
				else if (t instanceof UploadAbortedException)
				{
					json.put("status", "abort");
					json.put("title", "Upload aborted");
				}
				// Release the upload thread waiting in Upload.java
				synchronized (t)
				{
					t.notifyAll();
				}
			}
		}
	}
	else if ("Abort".equals(cmd))
	{
		final FileUploadProgress progress = sc.getSessionSetting("FileUploadProgress");
		if (progress != null) 
		{
			progress.setAbort();
			json.put("aborted", 1);
		}
		else
		{
			json.put("aborted", 0);
		}
	}
	else if ("CheckExistingFile".equals(cmd))
	{
		dc = sc.newDbControl(":Check if file exists");		
		try
		{
			Path path = new Path(request.getParameter("path"), Path.Type.FILE);
			File f = File.getByPath(dc, path, false);
			json.put("file", f.getName());
			json.put("fileExists", 1);
			json.put("fileSize", f.getSize());
		}
		catch (ItemNotFoundException ex)
		{
			json.put("fileExists", 0);
		}
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}
}
catch (Throwable t)
{
	json.clear();
	json.put("status", "error");
	json.put("message", t.getMessage());
	json.put("stacktrace", ThrowableUtil.stackTraceToString(t));
}
finally
{
	if (dc != null) dc.close();
	json.writeJSONString(out);
	out.flush();
}
%>