<%-- $Id: index.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.PlateType"
	import="net.sf.basedb.core.PlateEventType"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.util.RemovableUtil"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.edit.OnSaveAction"
	import="net.sf.basedb.clients.web.extensions.edit.OnSaveRenderer"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnExportRenderer"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnAction"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="net.sf.basedb.util.Values"
	import="java.util.List"
	import="java.util.Collections"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%!
	private static final ItemContext defaultContext = Base.createDefaultContext("ordinal", "name,ordinal,itemSubtype,description");
	private static final Item itemType = Item.PLATEEVENTTYPE;
%>
<%
final int plateTypeId = Values.getInt(request.getParameter("platetype_id"));

final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final String cmd = request.getParameter("cmd");
final String root = request.getContextPath()+"/";
final String mode = request.getParameter("mode");
final String callback = request.getParameter("callback");
final String itemId = request.getParameter("item_id");
final String listPage = "list_eventtypes.jsp?ID="+ID
	+"&platetype_id="+plateTypeId
	+(mode == null ? "" : "&mode="+mode)
	+(callback == null ? "" : "&callback="+callback)
	+(itemId == null ? "" : "&item_id="+itemId);
final String viewPage = "view_eventtype.jsp?ID="+ID+"&platetype_id="+plateTypeId;
final String editPage = "edit_eventtype.jsp?ID="+ID+"&platetype_id="+plateTypeId;

String forward = null;
String redirect = null;
String message = null;
DbControl dc = null;

try
{
	if (cmd == null || "List".equals(cmd))
	{
		// Display the list page without updatinging the current context
		Base.getAndSetCurrentContext(sc, itemType, null, defaultContext, true);
		redirect = listPage;
	}
	else if ("UpdateContext".equals(cmd))
	{
		// Display the list page after updating the current context from the request parameters
		Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = listPage;
	}
	else if ("LoadContext".equals(cmd))
	{
		// Display the list page after loading a saved context
		int contextId = Values.getInt(request.getParameter("context"));
		Base.loadContext(sc, contextId, defaultContext);
		redirect = listPage;
	}
	else if ("ViewItem".equals(cmd))
	{
		// Display the view page for a single item 
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		forward = viewPage;
	}
	else if ("EditItem".equals(cmd))
	{
		// Display the edit page for a single item (should be opened in a popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = editPage;
	}
	else if ("NewItem".equals(cmd))
	{
		// Display the edit page for a new item (should be opened in a popup)
		if (!sc.hasPermission(Permission.CREATE, itemType))
		{
			throw new PermissionDeniedException(Permission.CREATE, itemType.toString());
		}
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		cc.setId(0);
		redirect = editPage;
	}
	else if ("UpdateItem".equals(cmd))
	{
		// Update the properties on an item (will close the popup)
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, defaultContext);
		final int maxRecent = Base.getMaxRecent(sc);
		dc = sc.newDbControl(":Edit "+itemType);
		PlateEventType eventType = cc.getObject("item");
		if (eventType == null)
		{
			PlateType plateType = PlateType.getById(dc, plateTypeId);
			eventType = plateType.newEventType();
			message = "Event type created";
			dc.saveItem(eventType);
		}
		else
		{
			dc.reattachItem(eventType, false);
			message = "Event type updated";
		}
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(Item.PLATEEVENTTYPE), eventType);
		ExtensionsInvoker<OnSaveAction> invoker = EditUtil.useOnSaveExtensions(jspContext);
		try
		{
			eventType.setName(Values.getStringOrNull(request.getParameter("name")));
			eventType.setDescription(Values.getStringOrNull(request.getParameter("description")));
			eventType.setOrdinal(Values.getInt(request.getParameter("ordinal")));
			int protocolTypeId = Values.getInt(request.getParameter("protocoltype_id"), -1);
			if (protocolTypeId >= 0) // < 0 = denied or unchanged
			{
				ItemSubtype pt = protocolTypeId == 0 ? null : ItemSubtype.getById(dc, protocolTypeId);
				eventType.setProtocolType(pt);
				cc.setRecent(Item.ITEMSUBTYPE, pt, maxRecent);
			}
			
			// OnSave extensions
			invoker.render(OnSaveRenderer.ON_SAVE);
			dc.commit();
			invoker.render(OnSaveRenderer.ON_COMMIT);
		}
		catch (Exception ex)
		{
			invoker.render(OnSaveRenderer.onRollback(ex));
			throw ex;
		}
		finally
		{
			cc.removeObject("item");
		}
	}
	else if ("DeleteItem".equals(cmd))
	{
		// Delete a single item and then return to the view page
		dc = sc.newDbControl(":Delete "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		RemovableUtil.delete(dc, itemType, Collections.singleton(cc.getId()));
		dc.commit();
		redirect = listPage;
	}
	else if ("DeleteItems".equals(cmd))
	{
		// Delete all selected items on the list page
		dc = sc.newDbControl(":Delete "+itemType);
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		int numTotal = cc.getSelected().size();
		int numDeleted = RemovableUtil.delete(dc, itemType, cc.getSelected());
		dc.commit();
		if (numTotal != numDeleted)
		{
			message = (numDeleted == 0 ? "No" : "Only "+numDeleted+" of "+numTotal) + " items could be deleted, because you have no DELETE permission";
		}
		redirect = listPage;
	}
	else if ("ExportItems".equals(cmd))
	{
		// Run an export plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		dc = sc.newDbControl(":Export "+itemType);
		final PlateType plateType = PlateType.getById(dc, plateTypeId);
		final ItemQuery<PlateEventType> query = PlateEventType.getQuery(plateType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		cc.setQuery(query);
		ExtensionsInvoker<ListColumnAction<PlateEventType,?>> listInvoker = ListColumnUtil.useExtensions(jspContext);
		listInvoker.render(new ListColumnExportRenderer<PlateEventType>(cc));
		dc.close();
		redirect = "../../../common/export/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&title=Export+event+types";
	}
	else if ("ExportItem".equals(cmd))
	{
		// Run an export plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = "../../../common/export/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&title=Export+event+type";
	}
	else if ("ImportItems".equals(cmd))
	{
		// Run an import plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		dc = sc.newDbControl(":Import "+itemType);
		final PlateType plateType = PlateType.getById(dc, plateTypeId);
		final ItemQuery<PlateEventType> query = PlateEventType.getQuery(plateType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		dc.close();
		cc.setQuery(query);
		redirect = "../../../common/import/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&title=Import+event+types";
	}
	else if ("ImportItem".equals(cmd))
	{
		// Run an import plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = "../../../common/import/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&title=Import+event+type";
	}
	else if ("RunListPlugin".equals(cmd))
	{
		// Run another plugin in a list context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		dc = sc.newDbControl(":Run plugin "+itemType);
		final PlateType plateType = PlateType.getById(dc, plateTypeId);
		final ItemQuery<PlateEventType> query = PlateEventType.getQuery(plateType);
		JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.list(itemType), null);
		cc.configureQuery(dc, query, jspContext, true);
		dc.close();
		cc.setQuery(query);
		redirect = "../../../common/plugin/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=LIST&main_type=OTHER&title=Run+plugin";
	}
	else if ("RunPlugin".equals(cmd))
	{
		// Run another plugin in single-item context
		ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, pageContext, defaultContext);
		redirect = "../../../common/plugin/index.jsp?ID="+ID+"&cmd=SelectPlugin&item_type="+itemType.name()+"&context_type=ITEM&main_type=OTHER&title=Run+plugin";
	}
	else
	{
		throw new WebException("popup", "Invalid command", "The command {1} is not recognised as a valid command.", cmd);
	}

}
finally
{
	if (dc != null) dc.close();
}
if (forward != null)
{
	sc.setSessionSetting("alert-message", message);
	pageContext.forward(forward);
}
else if (redirect != null)
{
	sc.setSessionSetting("alert-message", message);
	response.sendRedirect(redirect);
}
else if (message == null)
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&wait=0");
}
else
{
	response.sendRedirect(root + "common/close_popup.jsp?refresh_opener=1&message="+HTML.urlEncode(message));
}

%>
