/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var JepIntensityTransformer = function()
{
	var jep = {};
	
	/**
		Initialize the page.
	*/
	jep.initPage = function()
	{

		// Preset formulas
		Events.addEventHandler('presets', 'change', jep.presetOnChange);
		
		Buttons.addClickHandler('btnNext', jep.goNext);
	}
	
	jep.initElements = function(element, autoInit)
	{
		if (autoInit == 'expression-builder')
		{
			Buttons.addClickHandler(element, JepPlugins.openExpressionBuilder);
		}
	}

	jep.presetOnChange = function(event)
	{
		var frm = document.forms['transformation'];
		var selected = frm.presets[frm.presets.selectedIndex];
		
		frm['parameter:transformationName'].value = selected.text;
		var numChannels = Data.int('page-data', 'num-channels');
		var formulas = Data.json(selected, 'formulas');
		for (var i = 0; i < formulas.length; i++)
		{
			frm['parameter:ch'+(i+1)+'.expression'].value = formulas[i];
		}
		Forms.selectListOption(frm['parameter:resultTransform'], Data.get(selected, 'transform'));
		frm.presets.selectedIndex = 0;
	}

	jep.validateParameters = function()
	{
		var frm = document.forms['transformation'];
		if (Strings.trim(frm['parameter:childName'].value) == '')
		{
			Forms.showNotification(frm['parameter:childName'], 'You must enter a name for the child bioassay set');
			return false;		
		}
		var numChannels = Data.int('page-data', 'num-channels');
		var maxRawMapping = Data.int('page-data', 'max-raw-mapping')
		for (var ch = 1; ch <= numChannels; ch++)
		{
			var inputName = 'parameter:ch'+ch+'.expression';
			if (Strings.trim(frm[inputName].value) == '')
			{
				Forms.showNotification(frm[inputName], 'You must enter an expression for channel ' + ch);
				return false;
			}
			else if (maxRawMapping != 1 && frm[inputName].value.search(/raw\(/) != -1)
			{
				Forms.showNotification(frm[inputName], 'Can\'t use function raw() for bioassaysets with multiple mappings to raw data');
				return false;
			}
		}
		return true;
	}
	
	jep.goNext = function()
	{
		if (!jep.validateParameters()) return;

		var frm = document.forms['transformation'];
		frm.submit();
	}
	

	return jep;
}();

Doc.onLoad(JepIntensityTransformer.initPage);
Doc.addElementInitializer(JepIntensityTransformer.initElements);


